@@ -262,8 +262,8 @@ class RestChannelAsyncClient:
         self,
         server_url: str,
         token: str,
-        on_resp_payload: Callable[[ResponseMessagePayloadPart], None],
-        on_hb_error: Optional[Callable[[Exception], None]] = None,
+        on_resp_payload: Callable[[str, ResponseMessagePayloadPart], None],
+        on_heartbeat: Optional[Callable[[Optional[Exception]], None]] = None,
         hb_interval_sec: float = DFLT_HB_INTERVAL_SEC
     ):
         """
@@ -275,15 +275,16 @@ class RestChannelAsyncClient:
             Authorization token for the requests.
         @param on_resp_payload :
             Callback to process each response payload part.
-        @param on_hb_error :
-            Optional callback for handling errors during C{heartbeat}.
+            The callback takes two arguments: a response ID and a payload part.
+        @param on_heartbeat :
+            An optional callback function to handle C{heartbeat} events.
         @param hb_interval_sec :
             Interval between C{heartbeat} requests, in seconds.
         """
         self._server_url = server_url
         self._headers = _mk_headers(token)
         self._on_resp_payload = on_resp_payload
-        self._on_hb_error = on_hb_error
+        self._on_heartbeat = on_heartbeat
         self._hb_interval_sec = hb_interval_sec
         self._thread = Thread(target=self._hb)
         self._stopped = False
@@ -335,7 +336,7 @@ class RestChannelAsyncClient:
         """
         if resp:
             for payload in resp.payload:
-                self._on_resp_payload(payload)
+                self._on_resp_payload(resp.resp_id, payload)
 
     def _hb(self) -> None:
         """
@@ -361,10 +362,13 @@ class RestChannelAsyncClient:
                     err = e
 
             if err:
-                if self._on_hb_error:
-                    self._on_hb_error(err)
+                if self._on_heartbeat:
+                    self._on_heartbeat(err)
                 else:
                     _logger.error(f'Error during sending heartbeat [error={err}]', exc_info=True)
+            else:
+                if self._on_heartbeat:
+                    self._on_heartbeat(None)
 
             self._on_srv_messages(resp)
 
